@@ -1,11 +1,15 @@
 use strict;
 use warnings;
-package App::Nopaste; # git description: 1.002-1-g2c0e995
-$App::Nopaste::VERSION = '1.003';
+package App::Nopaste; # git description: 1.004-20-g46505dd
+# ABSTRACT: Easy access to any pastebin
+# KEYWORDS: application executable paste output pastebin debugging
+
+our $VERSION = '1.005';
+
 use 5.008003;
 use Module::Pluggable search_path => 'App::Nopaste::Service', sub_name => '_plugins';
 use Class::Load 'load_class';
-use namespace::clean;
+use namespace::clean 0.19;
 
 use base 'Exporter';
 our @EXPORT_OK = 'nopaste';
@@ -82,10 +86,13 @@ sub nopaste {
 }
 
 1;
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =for stopwords nopaste pastebin
 
 =head1 NAME
@@ -94,7 +101,7 @@ App::Nopaste - Easy access to any pastebin
 
 =head1 VERSION
 
-version 1.003
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -185,4 +192,140 @@ Copyright 2008- Shawn M Moore.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, <sartak@gmail.com>
+
+=head1 CONTRIBUTORS
+
+=for stopwords Shawn M Moore Karen Etheridge Thomas Sibley François Gannaz Ricardo Signes Justin Hunter Kevin Falcone Zoffix Znet David Golden Dean Hamstead Sergey Romanov Jesse Luehrs Rafael Kitover Сергей Романов Arthur Axel 'fREW' Schmidt יובל קוג'מן (Yuval Kogman) Darian Anthony Patrick Bremner J. Shultz Graham Knop Jason Mills John Goulah Maximilian Gass Sebastian Paaske Tørholm Tatsuhiko Miyagawa gregor herrmann vti Ævar Arnfjörð Bjarmason
+
+=over 4
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Thomas Sibley <tsibley@cpan.org>
+
+=item *
+
+François Gannaz <francois.gannaz@silecs.info>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=item *
+
+Justin Hunter <justin.d.hunter@gmail.com>
+
+=item *
+
+Kevin Falcone <kevin@jibsheet.com>
+
+=item *
+
+Zoffix Znet <cpan@zoffix.com>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=item *
+
+Dean Hamstead <dean@fragfest.com.au>
+
+=item *
+
+Sergey Romanov <complefor@rambler.ru>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Rafael Kitover <rkitover@cpan.org>
+
+=item *
+
+Сергей Романов <sromanov@cpan.org>
+
+=item *
+
+Arthur Axel 'fREW' Schmidt <frioux@gmail.com>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Darian Anthony Patrick <dap@darianpatrick.com>
+
+=item *
+
+David Bremner <bremner@unb.ca>
+
+=item *
+
+David J. Shultz <djshultz@gmail.com>
+
+=item *
+
+Graham Knop <haarg@haarg.org>
+
+=item *
+
+Jason Mills <jmmills@cpan.org>
+
+=item *
+
+John Goulah <jgoulah@gmail.com>
+
+=item *
+
+Maximilian Gass <mxey@ghosthacking.net>
+
+=item *
+
+Sebastian Paaske Tørholm <Eckankar+github@gmail.com>
+
+=item *
+
+Tatsuhiko Miyagawa <miyagawa@bulknews.net>
+
+=item *
+
+gregor herrmann <gregoa@debian.org>
+
+=item *
+
+vti <viacheslav.t@gmail.com>
+
+=item *
+
+Ævar Arnfjörð Bjarmason <avarab@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
