@@ -1,12 +1,15 @@
 use strict;
 use warnings;
 package App::Nopaste::Command;
-$App::Nopaste::Command::VERSION = '1.003';
+# ABSTRACT: command-line utility for L<App::Nopaste>
+
+our $VERSION = '1.005';
+
 use Getopt::Long::Descriptive ();
 
 use App::Nopaste;
 use Module::Runtime 'use_module';
-use namespace::clean;
+use namespace::clean 0.19;
 
 sub new_with_options {
     my $class = shift;
@@ -141,10 +144,13 @@ sub read_text {
 }
 
 1;
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =for stopwords chan desc lang nopaste pastebot
 
 =head1 NAME
@@ -153,7 +159,7 @@ App::Nopaste::Command - command-line utility for L<App::Nopaste>
 
 =head1 VERSION
 
-version 1.003
+version 1.005
 
 =head1 DESCRIPTION
 
@@ -213,4 +219,20 @@ If specified, the paste access will be restricted to those that know the URL.
 
 If specified, do not warn or complain about broken services.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, <sartak@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
