@@ -1,7 +1,10 @@
 use strict;
 use warnings;
 package App::Nopaste::Service;
-$App::Nopaste::Service::VERSION = '1.003';
+# ABSTRACT: base class for nopaste services
+
+our $VERSION = '1.005';
+
 use WWW::Mechanize;
 
 sub available         { 1 }
@@ -91,10 +94,13 @@ sub return {
 }
 
 1;
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =for stopwords pastebot XXX chan desc lang mech nopaste canonicalization
 
 =head1 NAME
@@ -103,7 +109,7 @@ App::Nopaste::Service - base class for nopaste services
 
 =head1 VERSION
 
-version 1.003
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -181,4 +187,20 @@ pasted text.
 
 Shawn M Moore, C<< <sartak at gmail.com> >>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, <sartak@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
