@@ -2,7 +2,9 @@ use strict;
 use warnings;
 package App::Nopaste::Service::Codepeek;
 # ABSTRACT: (DEPRECATED) Service for Codepeek - http://codepeek.com
-our $VERSION = '1.004';
+
+our $VERSION = '1.005';
+
 use base 'App::Nopaste::Service';
 
 sub uri { 'http://codepeek.com/paste' }
@@ -47,7 +49,7 @@ App::Nopaste::Service::Codepeek - (DEPRECATED) Service for Codepeek - http://cod
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 DEPRECATION NOTICE
 
@@ -57,6 +59,11 @@ L<http://codepeek.com> is now offline, so this service no longer works.
 
 Justin Hunter, C<< <justin.d.hunter@gmail.com> >>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
 =head1 AUTHOR
 
 Shawn M Moore, <sartak@gmail.com>
