@@ -1,13 +1,16 @@
 use strict;
 use warnings;
 package App::Nopaste::Service::Gist;
-$App::Nopaste::Service::Gist::VERSION = '1.003';
+# ABSTRACT: Service provider for GitHub gist - http://gist.github.com/
+
+our $VERSION = '1.005';
+
 use base 'App::Nopaste::Service';
 
-use File::Basename ();
 use JSON::MaybeXS;
 use Module::Runtime 'use_module';
-use namespace::clean;
+use Path::Tiny;
+use namespace::clean 0.19;
 
 sub available         { 1 }
 sub forbid_in_default { 0 }
@@ -22,12 +25,12 @@ sub run {
     my $ua = LWP::UserAgent->new;
 
     my $content = {
-        public => defined $arg{private} ? 0 : 1,
+        public => defined $arg{private} ? JSON->false : JSON->true,
         defined $arg{desc} ? (description => $arg{desc}) : (),
     };
 
     my $filename = defined $arg{filename}
-                 ? File::Basename::basename($arg{filename})
+                 ? path($arg{filename})->basename->stringify
                  : 'nopaste';
 
     $content->{files} = {
@@ -47,7 +50,8 @@ sub run {
             $ua->post(
                 $url,
                 'Authorization' => "token $auth{oauth_token}",
-                Content         => $content
+                Content         => $content,
+                Content_Type    => 'application/json',
             );
         }
         else {
@@ -73,12 +77,25 @@ sub _get_auth {
             password => $ENV{GITHUB_PASSWORD},
         );
     }
+    else {
+        my $github_config = path('~', '.github');
+        if (-f $github_config) {
+            my $content = $github_config->slurp_utf8;
+            my ($username) = $content =~ m/\blogin (.+)(?:$|#)/m;
+            my ($password) = $content =~ m/\bpassword (.+)(?:$|#)/m;
+            return (
+                username => $username,
+                password => $password,
+            ) if $username and $password;
+        }
+    }
 
     die join("\n",
         "Export GITHUB_OAUTH_TOKEN first. For example:",
         "    perl -MApp::Nopaste::Service::Gist -e 'App::Nopaste::Service::Gist->create_token'",
         "",
         "OR you can export GITHUB_USER and GITHUB_PASSWORD.",
+        "OR you can set 'login' and 'password' in ~/.github.",
     ) . "\n";
 }
 
@@ -140,19 +157,22 @@ sub return {
 }
 
 1;
+
 __END__
 
 =pod
 
-=for stopwords SIGNES gists oauth
+=encoding UTF-8
 
 =head1 NAME
 
-App::Nopaste::Service::Gist - http://gist.github.com/
+App::Nopaste::Service::Gist - Service provider for GitHub gist - http://gist.github.com/
 
 =head1 VERSION
 
-version 1.003
+version 1.005
+
+=for stopwords SIGNES gists oauth plaintext
 
 =head1 GitHub Authorization
 
@@ -174,10 +194,31 @@ Alternatively, you can export the C<GITHUB_USER> and C<GITHUB_PASSWORD>
 environment variables, just like for the
 L<gist|https://github.com/defunkt/gist> utility.
 
+You can also simply store your credentials in plaintext in F<~/.github> as in:
+
+    login bob
+    password ilikeducks
+
 That's it!
 
 =head1 AUTHOR
 
 Ricardo SIGNES, C<< <rjbs@cpan.org> >>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, <sartak@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
