@@ -1,7 +1,10 @@
 use strict;
 use warnings;
 package App::Nopaste::Service::Mojopaste;
-$App::Nopaste::Service::Mojopaste::VERSION = '1.003';
+# ABSTRACT: Service provider for mojopaste
+
+our $VERSION = '1.005';
+
 use base 'App::Nopaste::Service';
 
 sub uri { $ENV{NOPASTE_MOJOPASTE_WEBPATH} || 'https://ssl.thorsen.pm/paste' }
@@ -39,19 +42,22 @@ sub return {
 
 
 1;
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =for stopwords mojopaste
 
 =head1 NAME
 
-App::Nopaste::Service::Mojopaste - A mojopaste instance
+App::Nopaste::Service::Mojopaste - Service provider for mojopaste
 
 =head1 VERSION
 
-version 1.003
+version 1.005
 
 =head1 USAGE
 
@@ -69,4 +75,20 @@ For example:
 
 Dean Hamstead, C<< <dean@bytefoundry.com.au> >>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, <sartak@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
