@@ -1,7 +1,10 @@
 use strict;
 use warnings;
 package App::Nopaste::Service::Ubuntu;
-$App::Nopaste::Service::Ubuntu::VERSION = '1.003';
+# ABSTRACT: Service provider for Ubuntu - http://paste.ubuntu.com/
+
+our $VERSION = '1.005';
+
 use base 'App::Nopaste::Service';
 
 my $languages = {
@@ -232,19 +235,22 @@ sub return {
 }
 
 1;
+
 __END__
 
 =pod
 
-=for stopwords Niebur
+=encoding UTF-8
 
 =head1 NAME
 
-App::Nopaste::Service::Ubuntu - http://paste.ubuntu.com/
+App::Nopaste::Service::Ubuntu - Service provider for Ubuntu - http://paste.ubuntu.com/
 
 =head1 VERSION
 
-version 1.003
+version 1.005
+
+=for stopwords Niebur
 
 =head1 AUTHOR
 
@@ -253,4 +259,20 @@ gregor herrmann, C<< <gregoa@debian.org> >>
 (Based on App::Nopaste::Service::Debian, written by
 Ryan Niebur, C<< <ryanryan52@gmail.com> >>)
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, <sartak@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
