@@ -1,13 +1,16 @@
 use strict;
 use warnings;
 package App::Nopaste::Service::ssh;
-$App::Nopaste::Service::ssh::VERSION = '1.003';
+# ABSTRACT: Copies files to your server using scp
+
+our $VERSION = '1.005';
+
 use base 'App::Nopaste::Service';
 use File::Temp;
 use File::Spec;
 use POSIX qw(strftime);
 use URI::Escape qw(uri_escape);
-use namespace::clean;
+use namespace::clean 0.19;
 
 sub run {
     my ($self, %args) = @_;
@@ -61,25 +64,22 @@ sub run {
 }
 
 1;
+
 __END__
 
 =pod
 
-=for stopwords dir
+=encoding UTF-8
 
 =head1 NAME
 
-App::Nopaste::Service::ssh - copies files to your server using scp
+App::Nopaste::Service::ssh - Copies files to your server using scp
 
 =head1 VERSION
 
-version 1.003
+version 1.005
 
-=head1 AUTHOR
-
-Kevin Falcone C<< <falcone@cpan.org> >>
-
-Thomas Sibley C<< <trs@bestpractical.com> >>
+=for stopwords dir
 
 =head1 ENVIRONMENT VARIABLES
 
@@ -125,4 +125,26 @@ It prevents common means of script execution so that C<.pl> and C<.cgi>
 files won't run and defaults the character set to UTF-8 so browsers
 don't have to guess wrong.
 
+=head1 AUTHOR
+
+Kevin Falcone C<< <falcone@cpan.org> >>
+
+Thomas Sibley C<< <trs@bestpractical.com> >>
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, <sartak@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
